
/****************************************************************************
** 
** File name   : sims_cap_chap5.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Predicted Probabilities for Demand of Discrimination (CAP) 
**			using Clarify (Tables 5.8 and 5.9)
** Requires    : replication_final.dta 
** Output      : sims_cap_chap5.log
** Info        : README
** NOTE	   : The simulation results cannot be exactly replicated because
**			they depend on random draws from the normal distribution
**			and the only way to ensure exact matches is to seed the 
**			random number generator with the same number (which I did
**			not do).	
**
****************************************************************************/


version 10

set more off
use replication_final, clear
drop if agriculture!=1
log using sims_cap_chap5.log, replace


estsimp probit demdisdum totagrn totagro sizen contribution erwerblandn bipn_eu100 expbip polityivnew,cluster (oldmember)

/*
positive-totagrn totagro sizen contribution erwerblandn 
negative-bipn_eu100 expbip polityivnew
*/

*__________TOTAGRN_____________________________________________________-

*Rest p25*
setx totagrn p25 (totagro sizen contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx totagrn median (totagro sizen contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx totagrn p75 (totagro sizen contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

*Rest median*

setx totagrn p25 (totagro sizen contribution erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 

setx  median 
simqi, pr 

setx totagrn p75 (totagro sizen contribution erwerblandn bipn_eu100 expbip polityivnew) median
simqi, pr 

*Rest p75*

*Rest p25*
setx totagrn p25 (totagro sizen contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx totagrn median (totagro sizen contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx totagrn p75 (totagro sizen contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 



*__________TOTAGRO_____________________________________________________-

*Rest p25*
setx totagro p25 (totagrn sizen contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx totagro median (totagrn sizen contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx totagro p75 (totagrn sizen contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

*Rest median*

setx totagro p25 (totagrn sizen contribution erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 

setx  median 
simqi, pr 

setx totagro p75 (totagrn sizen contribution erwerblandn bipn_eu100 expbip polityivnew) median
simqi, pr 

*Rest p75*

*Rest p25*
setx totagro p25 (totagrn sizen contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx totagro median (totagrn sizen contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx totagro p75 (totagrn sizen contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 


*__________SIZEN_____________________________________________________-

*Rest p25*
setx sizen 6 (totagro totagrn contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx sizen 9 (totagro totagrn contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx sizen 12 (totagro totagrn contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx sizen 15 (totagro totagrn contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx sizen 25 (totagro totagrn contribution erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

*Rest median*

setx sizen 6 (totagro totagrn contribution erwerblandn bipn_eu100 expbip polityivnew) median
simqi, pr 

setx sizen 9 (totagro totagrn contribution erwerblandn bipn_eu100 expbip polityivnew) median
simqi, pr 

setx sizen 12  (totagro totagrn contribution erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 

setx sizen 15  (totagro totagrn contribution erwerblandn bipn_eu100 expbip polityivnew) median
simqi, pr 

setx sizen 25  (totagro totagrn contribution erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 


*Rest p75*

setx sizen 6 (totagro totagrn contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx sizen 9 (totagro totagrn contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx sizen 12 (totagro totagrn contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx sizen 15 (totagro totagrn contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx sizen 25 (totagro totagrn contribution erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 




*__________CONTRIBUTION_____________________________________________________-

*Rest p25*
setx contribution p25 (totagrn sizen totagro erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx contribution median (totagrn sizen totagro erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx contribution p75 (totagrn sizen totagro erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

*Rest median*

setx contribution p25 (totagrn sizen totagro erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 

setx  median 
simqi, pr 

setx contribution p75 (totagrn sizen totagro erwerblandn bipn_eu100 expbip polityivnew) median
simqi, pr 

*Rest p75*

*Rest p25*
setx contribution p25 (totagrn sizen totagro erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx contribution median (totagrn sizen totagro erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx contribution p75 (totagrn sizen totagro erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 


*__________GROUP IMPACT_____________________________________________________-

*Rest p25*
setx (contribution totagrn sizen totagro) p25 (erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx (contribution totagrn sizen totagro) median (erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

setx (contribution totagrn sizen totagro) p75 (erwerblandn) p25 (bipn_eu100 expbip polityivnew) p75 
simqi, pr 

*Rest median*

*Rest p25*
setx (contribution totagrn sizen totagro) p25 (erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 

setx (contribution totagrn sizen totagro) median (erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 

setx (contribution totagrn sizen totagro) p75 (erwerblandn bipn_eu100 expbip polityivnew) median 
simqi, pr 

*Rest p75*

setx (contribution totagrn sizen totagro) p25 (erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx (contribution totagrn sizen totagro) median (erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 

setx (contribution totagrn sizen totagro) p75 (erwerblandn) p75 (bipn_eu100 expbip polityivnew) p25 
simqi, pr 


log close
