
/****************************************************************************
** 
** File name   : sims_csp_chap5.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Predicted Probabilities for Demand of Discrimination (CSP) 
**			using Clarify (Table 5.12 and 5.13)
** Requires    : replication_final.dta 
** Output      : sims_csp_chap5.log
** Info        : README
** NOTE	   : The simulation results cannot be exactly replicated because
**			they depend on random draws from the normal distribution
**			and the only way to ensure exact matches is to seed the 
**			random number generator with the same number (which I did
**			not do).	
**
****************************************************************************/

version 10

set more off
use replication_final, clear
drop if structuralfunds!=1
log using sims_csp_chap5.log, replace


estsimp probit demdisdum  bipn_eu100  fundo sizen erwerbindn erwerblandn contribution expbip polityivnew, cluster(oldmember) 

/* negative-bipn_eu100 contribution expbip
positive-fundo sizen erwerbindn erwerblandn  polityivnew*/


*__________CANDIDATE GDP_____________________________________________________-

*Rest p25*
setx bipn_eu100 p75 (fundo sizen erwerbindn erwerblandn  polityivnew) p25 (contribution expbip) p75 
simqi, pr 

setx bipn_eu100 median (fundo sizen erwerbindn erwerblandn  polityivnew) p25 (contribution expbip) p75 
simqi, pr 

setx bipn_eu100 p25 (fundo sizen erwerbindn erwerblandn  polityivnew) p25 (contribution expbip) p75 
simqi, pr 

*Rest median*

setx bipn_eu100 p75 (fundo sizen erwerbindn erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

setx bipn_eu100 median (fundo sizen erwerbindn erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

setx bipn_eu100 p25 (fundo sizen erwerbindn erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

*Rest p75*

setx bipn_eu100 p75 (fundo sizen erwerbindn erwerblandn  polityivnew) p75 (contribution expbip) p25 
simqi, pr 

setx bipn_eu100 median (fundo sizen erwerbindn erwerblandn  polityivnew) p75 (contribution expbip) p25 
simqi, pr 

setx bipn_eu100 p25 (fundo sizen erwerbindn erwerblandn  polityivnew) p75 (contribution expbip) p25 
simqi, pr 


*__________FUNDO_____________________________________________________-

*Rest p25*
setx fundo  p25 (sizen erwerbindn erwerblandn  polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

setx fundo  median (sizen erwerbindn erwerblandn  polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

setx fundo  p75 (sizen erwerbindn erwerblandn  polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

*Rest median*

setx fundo  p25 (bipn_eu100 sizen erwerbindn erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

setx fundo  median (bipn_eu100 sizen erwerbindn erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

setx fundo  p75 (bipn_eu100 sizen erwerbindn erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

*Rest p75*

setx fundo  p25 (sizen erwerbindn erwerblandn  polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 

setx fundo  median (sizen erwerbindn erwerblandn  polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 

setx fundo  p75 (sizen erwerbindn erwerblandn  polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 


*__________ERWERBINDN_____________________________________________________-

*Rest p25*
setx erwerbindn p25 (sizen fundo erwerblandn  polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

setx erwerbindn median (sizen fundo erwerblandn  polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

setx erwerbindn p75 (sizen fundo erwerblandn  polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

*Rest median*

setx erwerbindn p25 (bipn_eu100 sizen fundo erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

setx erwerbindn median (bipn_eu100 sizen fundo erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

setx erwerbindn p75 (bipn_eu100 sizen fundo erwerblandn  polityivnew contribution expbip) median 
simqi, pr 

*Rest p75*

setx erwerbindn p25 (sizen fundo erwerblandn  polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 

setx erwerbindn median (sizen fundo erwerblandn  polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 

setx erwerbindn p75 (sizen fundo erwerblandn  polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 



*__________ERWERBLANDN_____________________________________________________-

*Rest p25*
setx erwerblandn p25 (sizen fundo erwerbindn polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

setx erwerblandn median (sizen fundo erwerbindn polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

setx erwerblandn p75 (sizen fundo erwerbindn polityivnew) p25 (bipn_eu100 contribution expbip) p75 
simqi, pr 

*Rest median*

setx erwerblandn p25 (bipn_eu100 sizen fundo erwerbindn polityivnew contribution expbip) median 
simqi, pr 

setx erwerblandn median (bipn_eu100 sizen fundo erwerbindn polityivnew contribution expbip) median 
simqi, pr 

setx erwerblandn p75 (bipn_eu100 sizen fundo erwerbindn polityivnew contribution expbip) median 
simqi, pr 

*Rest p75*

setx erwerblandn p25 (sizen fundo erwerbindn polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 

setx erwerblandn median (sizen fundo erwerbindn polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 

setx erwerblandn p75 (sizen fundo erwerbindn polityivnew) p75 (bipn_eu100 contribution expbip) p25 
simqi, pr 


*__________EU BUDGET CONTRIBUTION_____________________________________________________-

*Rest p25*
setx contribution p75 (fundo sizen erwerbindn erwerblandn  polityivnew) p25 (bipn_eu100 expbip) p75 
simqi, pr 

setx contribution  median (fundo sizen erwerbindn erwerblandn  polityivnew) p25 (bipn_eu100 expbip) p75 
simqi, pr 

setx contribution  p25 (fundo sizen erwerbindn erwerblandn  polityivnew) p25 (bipn_eu100 expbip) p75 
simqi, pr 

*Rest median*

setx contribution  p75 (fundo sizen erwerbindn erwerblandn  polityivnew bipn_eu100 expbip) median 
simqi, pr 

setx contribution  median (fundo sizen erwerbindn erwerblandn  polityivnew bipn_eu100 expbip) median 
simqi, pr 

setx contribution  p25 (fundo sizen erwerbindn erwerblandn  polityivnew bipn_eu100 expbip) median 
simqi, pr 

*Rest p75*

setx contribution  p75 (fundo sizen erwerbindn erwerblandn  polityivnew) p75 (bipn_eu100 expbip) p25 
simqi, pr 

setx contribution  median (fundo sizen erwerbindn erwerblandn  polityivnew) p75 (bipn_eu100 expbip) p25 
simqi, pr 

setx contribution  p25 (fundo sizen erwerbindn erwerblandn  polityivnew) p75 (bipn_eu100 expbip) p25 
simqi, pr 



*__________GROUP IMPACT_____________________________________________________-

*Rest p25*
setx (erwerblandn fundo erwerbindn) p25 (bipn_eu100 contribution) p75 (sizen polityivnew) p25 ( expbip) p75 
simqi, pr 

setx (erwerblandn fundo erwerbindn bipn_eu100 contribution) median (sizen polityivnew) p25 ( expbip) p75 
simqi, pr 

setx (erwerblandn fundo erwerbindn) p75 (bipn_eu100 contribution) p25 (sizen polityivnew) p25 ( expbip) p75 
simqi, pr 

*Rest median*

setx (erwerblandn fundo erwerbindn) p25 (bipn_eu100 contribution) p75 (sizen polityivnew  expbip) median 
simqi, pr 

setx (erwerblandn fundo erwerbindn bipn_eu100 contribution) median (sizen polityivnew expbip) median 
simqi, pr 

setx (erwerblandn fundo erwerbindn) p75 (bipn_eu100 contribution) p25 (sizen polityivnew  expbip) median 
simqi, pr 

 
*Rest p75*

setx (erwerblandn fundo erwerbindn) p25 (bipn_eu100 contribution) p75 (sizen polityivnew) p75 ( expbip) p25 
simqi, pr 

setx (erwerblandn fundo erwerbindn bipn_eu100 contribution) median (sizen polityivnew) p75 ( expbip) p25 
simqi, pr 

setx (erwerblandn fundo erwerbindn) p75 (bipn_eu100 contribution) p25 (sizen polityivnew) p75 ( expbip) p25 
simqi, pr 


log close