/****************************************************************************
** 
** File name   : sims_fmw_chap5.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Predicted Probabilities for Demand of Discrimination (FMW) 
**			using Clarify (Tables 5.3 and 5.4)
** Requires    : replication_final.dta 
** Output      : sims_fmw_chap5.log
** Info        : README
** NOTE	   : The simulation results cannot be exactly replicated because
**			they depend on random draws from the normal distribution
**			and the only way to ensure exact matches is to seed the 
**			random number generator with the same number (which I did
**			not do).	
**
****************************************************************************/

version 10

set more off
use replication_final, clear
drop if freedomofmovement!=1
log using sims_fmw_chap5.log, replace


*__________FOREIGNERS_____________________________________________________-

**Share of Foreigners**
estsimp probit  demdisdum bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo expbip polityivnew contribution pop65perc, cluster(oldmembers)

/*
bipn_eu100-negative
distance-negative
unemplo-negative
expbip-negative
polityivnew-negative 
contribution-negative 

pop65perc-positive
foreign-positive
erwerbindo-positive
erwerbindn-positive
unempln-positive
*/

*Rest p25*
setx (foreign erwerbindo erwerbindn unempln pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx foreign median (erwerbindo erwerbindn unempln pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx foreign p75 (erwerbindo erwerbindn unempln pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75
simqi, pr 

*Rest median*

setx foreign p25 (erwerbindo erwerbindn unempln expbip polityivnew contribution bipn_eu100 distance unemplo pop65perc) median
simqi, pr  

setx  median 
simqi, pr 

setx foreign p75  (erwerbindo erwerbindn unempln expbip polityivnew contribution bipn_eu100 distance unemplo pop65perc) median
simqi, pr 

*Rest p75*

*Rest p25*
setx (foreign) p25 (erwerbindo erwerbindn unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx foreign median (erwerbindo erwerbindn unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx foreign p75 (erwerbindo erwerbindn unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr 

*________CANDIDATE GDP_________________________________________________________________


*Rest p25*
setx  bipn_eu100 p75 (foreign erwerbindo erwerbindn unempln pop65perc) p25 (distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx bipn_eu100 median (foreign erwerbindo erwerbindn unempln pop65perc) p25 (distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx bipn_eu100 p25 (foreign erwerbindo erwerbindn unempln pop65perc) p25 (distance unemplo expbip polityivnew contribution) p75
simqi, pr 

*Rest median*

setx bipn_eu100 p75 (foreign erwerbindo erwerbindn unempln expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr  

setx  median 
simqi, pr 

setx bipn_eu100 p25  (foreign erwerbindo erwerbindn unempln expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr 

*Rest p75*

*Rest p25*
setx bipn_eu100  p75 (foreign erwerbindo erwerbindn unempln pop65perc) p75 (distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx bipn_eu100 median (foreign erwerbindo erwerbindn unempln pop65perc) p75 (distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx bipn_eu100 p25 (foreign erwerbindo erwerbindn unempln pop65perc) p75 (distance unemplo expbip polityivnew contribution) p25 
simqi, pr 

*________EU MEMBER INDUSTRY EMPLOYMENT_________________________________________________________________


*Rest p25*
setx  erwerbindo  p25 (foreign erwerbindn unempln pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx  erwerbindo  median (foreign erwerbindn unempln pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx erwerbindo   p75 (foreign erwerbindn unempln pop65perc) p25 ( bipn_eu100 distance unemplo expbip polityivnew contribution) p75
simqi, pr 

*Rest median*

setx erwerbindo   p25 (bipn_eu100 foreign erwerbindn unempln expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr  

setx  median 
simqi, pr 

setx erwerbindo   p75  ( bipn_eu100 foreign erwerbindn unempln expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr 

*Rest p75*

*Rest p25*
setx erwerbindo    p25 (foreign erwerbindn unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx erwerbindo   median (foreign erwerbindn unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx erwerbindo   p75 (foreign erwerbindn unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr 

*________APPLICANT INDUSTRY EMPLOYMENT_________________________________________________________________


*Rest p25*
setx  erwerbindn  p25 (foreign erwerbindo unempln pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx  erwerbindn  median (foreign erwerbindo unempln pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx erwerbindn   p75 (foreign erwerbindo unempln pop65perc) p25 ( bipn_eu100 distance unemplo expbip polityivnew contribution) p75
simqi, pr 

*Rest median*

setx erwerbindn   p25 (bipn_eu100 foreign erwerbindo unempln expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr  

setx  median 
simqi, pr 

setx erwerbindn   p75  ( bipn_eu100 foreign erwerbindo unempln expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr 

*Rest p75*

*Rest p25*
setx erwerbindn    p25 (foreign erwerbindo unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx erwerbindn   median (foreign erwerbindo unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx erwerbindn   p75 (foreign erwerbindo unempln pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr 


*________APPLICANT UNEMPLOYMENT_________________________________________________________________


*Rest p25*
setx  unempln  p25 (foreign erwerbindo erwerbindn  pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx  unempln  median (foreign erwerbindo erwerbindn  pop65perc) p25 (bipn_eu100 distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx unempln  p75 (foreign erwerbindo erwerbindn  pop65perc) p25 ( bipn_eu100 distance unemplo expbip polityivnew contribution) p75
simqi, pr 

*Rest median*

setx unempln  p25 (bipn_eu100 foreign erwerbindo erwerbindn  expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr  

setx  median 
simqi, pr 

setx unempln  p75  ( bipn_eu100 foreign erwerbindo erwerbindn  expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr 

*Rest p75*

*Rest p25*
setx unempln  p25 (foreign erwerbindo erwerbindn  pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx unempln  median (foreign erwerbindo erwerbindn  pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx unempln  p75 (foreign erwerbindo erwerbindn  pop65perc) p75 (bipn_eu100 distance unemplo expbip polityivnew contribution) p25 
simqi, pr 

*___________GROUP IMPACT___________________


/*
bipn_eu100-negative
foreign-positive
erwerbindo-positive
erwerbindn-positive
unempln-positive

*/


*Rest p25*
setx  bipn_eu100 p75 (foreign erwerbindo erwerbindn unempln) p25 (pop65perc) p25 (distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx bipn_eu100 median (foreign erwerbindo erwerbindn unempln) median (pop65perc) p25 (distance unemplo expbip polityivnew contribution) p75 
simqi, pr 

setx bipn_eu100 p25 (foreign erwerbindo erwerbindn unempln) p75 (pop65perc) p25 (distance unemplo expbip polityivnew contribution) p75
simqi, pr 

*Rest median*

setx bipn_eu100 p75 (foreign erwerbindo erwerbindn unempln) p25 (expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr  

setx  median 
simqi, pr 

setx bipn_eu100 p25  (foreign erwerbindo erwerbindn unempln) p75 (expbip polityivnew contribution distance unemplo pop65perc) median
simqi, pr 

*Rest p75*

*Rest p25*
setx bipn_eu100  p75 (foreign erwerbindo erwerbindn unempln) p25 (pop65perc) p75 (distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx bipn_eu100 median (foreign erwerbindo erwerbindn unempln) median (pop65perc) p75 (distance unemplo expbip polityivnew contribution) p25 
simqi, pr  

setx bipn_eu100 p25 (foreign erwerbindo erwerbindn unempln) p75 (pop65perc) p75 (distance unemplo expbip polityivnew contribution) p25 
simqi, pr 


